# libpythonpro
Modulo para exemplificar projetos de Python do curso Pytools

Nesse curso é ensinado como contrubuir para projetos com codigo aberto

Suporta Python 3

[![Build Status](https://travis-ci.com/raolbrito/libpythonpro.svg?branch=master)](https://travis-ci.com/raolbrito/libpythonpro)


Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip isntall -r requiriments-dev.txt
```
Para conferir qualidade do codigo:

```console
flake8
```
